@@ -3,14 +3,15 @@
 #' @template arg_parameters
 #'
 #' @examples
-#'  ## Read the parameters directly from text
-#'  parameters_tab <-
-#' 'a "" i (2, 10)
-#'  b "" c (yes, no) | a < 5
-#'  c "" r (10, 50)  | a == 2 || b == "yes"
-#'  '
-#'  parameters <- irace::readParameters(text=parameters_tab)
-#'  parameters_tree(parameters)
+#' # Read the parameters directly from text.
+#' parameters_tab <- '
+#' a "" i (2, 10)
+#' b "" c (yes, no) | a < 5
+#' c "" o (low, medium, high) | (a == 2) | (b == "yes")
+#' d "" r (a, 50)
+#' '
+#' parameters <- irace::readParameters(text=parameters_tab)
+#' parameters_tree(parameters)
 #' 
 #' @author Manuel López-Ibáñez
 #' @export
@@ -22,7 +23,7 @@ parameters_tree <- function(parameters)
   
   revtree <- lapply(params, function(y)
     params[sapply(depends, function(x, elem) elem %in% x, elem = y)])
-  revtree <- c(list(params[sapply(depends, length) == 0]), revtree)
+  revtree <- c(list(params[sapply(depends, length) == 0L]), revtree)
   revdep <- data.frame(stringsAsFactors = FALSE,
                        parameter = c(" ", params),
                        dependencies = I(revtree))
